==> zio-aws-computeoptimizer_3-5.17.157.1-sources.jar: zio/aws/computeoptimizer/model/EBSFilter.scala <==
package zio.aws.computeoptimizer.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.computeoptimizer.model.primitives.FilterValue
import scala.jdk.CollectionConverters.*
final case class EBSFilter(
    name: Option[zio.aws.computeoptimizer.model.EBSFilterName] = None,
    values: Option[Iterable[FilterValue]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.computeoptimizer.model.EBSFilter = {
    import EBSFilter.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.computeoptimizer.model.EBSFilter
      .builder()
      .optionallyWith(name.map(value => value.unwrap))(_.name)
      .optionallyWith(
        values.map(value =>
          value.map { item =>
            FilterValue.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.values)
      .build()
  }
  def asReadOnly: zio.aws.computeoptimizer.model.EBSFilter.ReadOnly =
    zio.aws.computeoptimizer.model.EBSFilter.wrap(buildAwsValue())
}
object EBSFilter {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.computeoptimizer.model.EBSFilter
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.computeoptimizer.model.EBSFilter =
      zio.aws.computeoptimizer.model
        .EBSFilter(name.map(value => value), values.map(value => value))
    def name: Option[zio.aws.computeoptimizer.model.EBSFilterName]
    def values: Option[List[FilterValue]]
    def getName
        : ZIO[Any, AwsError, zio.aws.computeoptimizer.model.EBSFilterName] =
      AwsError.unwrapOptionField("name", name)
    def getValues: ZIO[Any, AwsError, List[FilterValue]] =
      AwsError.unwrapOptionField("values", values)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.computeoptimizer.model.EBSFilter
  ) extends zio.aws.computeoptimizer.model.EBSFilter.ReadOnly {
    override val name: Option[zio.aws.computeoptimizer.model.EBSFilterName] =
      scala
        .Option(impl.name())
        .map(value => zio.aws.computeoptimizer.model.EBSFilterName.wrap(value))
    override val values: Option[List[FilterValue]] = scala
      .Option(impl.values())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.computeoptimizer.model.primitives.FilterValue(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.computeoptimizer.model.EBSFilter
  ): zio.aws.computeoptimizer.model.EBSFilter.ReadOnly = new Wrapper(impl)
}

==> zio-aws-computeoptimizer_3-5.17.208.1-sources.jar: zio/aws/computeoptimizer/model/EBSFilter.scala <==
package zio.aws.computeoptimizer.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.computeoptimizer.model.primitives.FilterValue
import scala.jdk.CollectionConverters.*
final case class EBSFilter(
    name: Optional[zio.aws.computeoptimizer.model.EBSFilterName] =
      Optional.Absent,
    values: Optional[Iterable[FilterValue]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.computeoptimizer.model.EBSFilter = {
    import EBSFilter.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.computeoptimizer.model.EBSFilter
      .builder()
      .optionallyWith(name.map(value => value.unwrap))(_.name)
      .optionallyWith(
        values.map(value =>
          value.map { item =>
            FilterValue.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.values)
      .build()
  }
  def asReadOnly: zio.aws.computeoptimizer.model.EBSFilter.ReadOnly =
    zio.aws.computeoptimizer.model.EBSFilter.wrap(buildAwsValue())
}
object EBSFilter {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.computeoptimizer.model.EBSFilter
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.computeoptimizer.model.EBSFilter =
      zio.aws.computeoptimizer.model
        .EBSFilter(name.map(value => value), values.map(value => value))
    def name: Optional[zio.aws.computeoptimizer.model.EBSFilterName]
    def values: Optional[List[FilterValue]]
    def getName
        : ZIO[Any, AwsError, zio.aws.computeoptimizer.model.EBSFilterName] =
      AwsError.unwrapOptionField("name", name)
    def getValues: ZIO[Any, AwsError, List[FilterValue]] =
      AwsError.unwrapOptionField("values", values)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.computeoptimizer.model.EBSFilter
  ) extends zio.aws.computeoptimizer.model.EBSFilter.ReadOnly {
    override val name: Optional[zio.aws.computeoptimizer.model.EBSFilterName] =
      zio.aws.core.internal
        .optionalFromNullable(impl.name())
        .map(value => zio.aws.computeoptimizer.model.EBSFilterName.wrap(value))
    override val values: Optional[List[FilterValue]] = zio.aws.core.internal
      .optionalFromNullable(impl.values())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.computeoptimizer.model.primitives.FilterValue(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.computeoptimizer.model.EBSFilter
  ): zio.aws.computeoptimizer.model.EBSFilter.ReadOnly = new Wrapper(impl)
}
